---
title: Nightly Azure Wheel Fail on {{ date | date('ddd, MMMM Do YYYY') }}
assignees: nguyenv, ihnorton
labels: bug
---

See run for more details:
https://dev.azure.com/TileDB-Inc/CI/_build/results?buildId=${{ env.AZURE_BUILD_ID }}&view=results